Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(963)

Unified Diff: src/mips/code-stubs-mips.cc

Issue 11028027: Revert trunk to bleeding_edge at r12484 (Closed) Base URL: https://v8.googlecode.com/svn/trunk
Patch Set: Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/messages.js ('k') | src/mips/full-codegen-mips.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/mips/code-stubs-mips.cc
diff --git a/src/mips/code-stubs-mips.cc b/src/mips/code-stubs-mips.cc
index ee3127aafd71e0fe8dff6607aa8d8a12384474c6..a5c80b8471c9f34dbc19916e2e3ba631876db076 100644
--- a/src/mips/code-stubs-mips.cc
+++ b/src/mips/code-stubs-mips.cc
@@ -5405,12 +5405,12 @@ void RegExpConstructResultStub::Generate(MacroAssembler* masm) {
// Set FixedArray length.
__ sll(t2, t1, kSmiTagSize);
__ sw(t2, FieldMemOperand(a3, FixedArray::kLengthOffset));
- // Fill contents of fixed-array with undefined.
- __ LoadRoot(a2, Heap::kUndefinedValueRootIndex);
+ // Fill contents of fixed-array with the-hole.
+ __ li(a2, Operand(masm->isolate()->factory()->the_hole_value()));
__ Addu(a3, a3, Operand(FixedArray::kHeaderSize - kHeapObjectTag));
// Fill fixed array elements with undefined.
// v0: JSArray, tagged.
- // a2: undefined.
+ // a2: the hole.
// a3: Start of elements in FixedArray.
// t1: Number of elements to fill.
Label loop;
@@ -7512,11 +7512,6 @@ void RecordWriteStub::GenerateFixedRegStubsAheadOfTime() {
}
-bool CodeStub::CanUseFPRegisters() {
- return CpuFeatures::IsSupported(FPU);
-}
-
-
// Takes the input in 3 registers: address_ value_ and object_. A pointer to
// the value has just been written into the object, now this stub makes sure
// we keep the GC informed. The word in the object where the value has been
@@ -5405,12 +5405,12 @@ void RegExpConstructResultStub::Generate(MacroAssembler* masm) {
__ Addu(a3, a3, Operand(FixedArray::kHeaderSize - kHeapObjectTag));
- // Fill fixed array elements with undefined.
+ // Fill fixed array elements with hole.
// v0: JSArray, tagged.
« no previous file with comments | « src/messages.js ('k') | src/mips/full-codegen-mips.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698